@@ -1,6 +1,7 @@
 import numpy as np
 import json
 import cv2
+import zebrazoom.videoFormatConversion.zzVideoReading as zzVideoReading
 import math
 from zebrazoom.code.getHyperparameters import getHyperparametersSimple
 from zebrazoom.code.getImage.getForegroundImage import getForegroundImage
@@ -35,7 +36,7 @@ def getGroundTruthFromUser(self, controller, nbOfImagesToManuallyClassify, saveI
   initialHyperparameters["videoName"]      = videoName
   wellPositions = findWells(os.path.join(pathToVideo, videoNameWithExt), initialHyperparameters)
   
-  cap   = cv2.VideoCapture(videoPath)
+  cap   = zzVideoReading.VideoCapture(videoPath)
   max_l = int(cap.get(7))
   
   # Finding the well with the most movement
@@ -44,6 +45,10 @@ def getGroundTruthFromUser(self, controller, nbOfImagesToManuallyClassify, saveI
   firstFrame = cv2.cvtColor(firstFrame, cv2.COLOR_BGR2GRAY)
   cap.set(1, max_l-1)
   ret, lastFrame = cap.read()
+  while not(ret):
+    max_l = max_l - 1
+    cap.set(1, max_l-1)
+    ret, lastFrame = cap.read()
   lastFrame = cv2.cvtColor(lastFrame, cv2.COLOR_BGR2GRAY)
   pixelsChange = np.zeros((len(wellPositions)))
   for wellNumberId in range(0, len(wellPositions)):
@@ -53,7 +58,7 @@ def getGroundTruthFromUser(self, controller, nbOfImagesToManuallyClassify, saveI
     lenY  = wellPositions[wellNumberId]['lengthY']
     firstFrameROI = firstFrame[ytop:ytop+lenY, xtop:xtop+lenX]
     lastFrameROI  = lastFrame[ytop:ytop+lenY, xtop:xtop+lenX]
-    pixelsChange[wellNumberId] = np.sum(abs(firstFrameROI-lastFrameROI))
+    pixelsChange[wellNumberId] = np.sum(abs(firstFrameROI-lastFrameROI)) / np.sum(abs(firstFrameROI)) if np.sum(abs(firstFrameROI)) else 0
   wellNumber = np.argmax(pixelsChange)
   
   backCalculationStep = int(max_l / nbOfImagesToManuallyClassify)
@@ -306,7 +311,7 @@ def boutDetectionParameters(data, configFile, pathToVideo, videoName, videoExt,
 
   # Finding the frame with the most movement
   
-  cap   = cv2.VideoCapture(videoPath)
+  cap   = zzVideoReading.VideoCapture(videoPath)
   max_l = int(cap.get(7))
   
   wellNumber = data[0]["wellNumber"]
@@ -334,6 +339,10 @@ def boutDetectionParameters(data, configFile, pathToVideo, videoName, videoExt,
     
     cap.set(1, lastFrameNum)
     ret, lastFrame = cap.read()
+    while not(ret):
+      lastFrameNum = lastFrameNum - 1
+      cap.set(1, lastFrameNum)
+      ret, lastFrame = cap.read()
     lastFrame = cv2.cvtColor(lastFrame, cv2.COLOR_BGR2GRAY)
     
     firstFrameROI  = firstFrame[ytop:ytop+lenY, xtop:xtop+lenX]
